DataTreeWidget — pyqtgraph 0.11.0rc0 documentation

# DataTreeWidget

class `pyqtgraph.` `DataTreeWidget`(parent=None, data=None)

  Widget for displaying hierarchical python data structures (eg, nested dicts, lists, and arrays)

  `__init__`(parent=None, data=None)

    Initialize self. See help(type(self)) for accurate signature.

  `parse`(data)

    Given any python object, return: * type * a short string representation * a dict of sub-objects to be parsed * optional widget to display as sub-node

  `setData`(data, hideRoot=False)

    data should be a dictionary.